=======
History
=======

0.1.0 (2020-01-02)
------------------

* First release on PyPI.

0.2.0 (2018-02-13)
------------------

* Major feature implementation and documentation
* Static typing
* Testing - 44% coverage

